def dividenum(x, y):
    divide = x / y
    print("Hello Poojaa")
    return divide


def multiplynum(x, y):
    multiply = x * y
    return multiply


def addnumber(x, y):
    add = x + y
    return add


def subnum(x, y):
    sub = x - y
    return sub
